==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/escape/EscapingStmtSwitch.h <==
// public class org.dellroad.jc.cgen.escape.EscapingStmtSwitch

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 535ab0352e3db9e7 org_dellroad_jc_cgen_escape_EscapingStmtSwitch
// @dep_class d048eaf64ce6dc1a soot_jimple_AbstractStmtSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractStmtSwitch

#include "soot/jimple/AbstractStmtSwitch.h"

#ifndef _JC_org_dellroad_jc_cgen_escape_EscapingStmtSwitch_H_
#define _JC_org_dellroad_jc_cgen_escape_EscapingStmtSwitch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_org_dellroad_jc_cgen_escape_EscapingValueSwitch$object;
struct _jc_soot_Local$object;
struct _jc_soot_jimple_AssignStmt$object;
struct _jc_soot_jimple_InvokeStmt$object;
struct _jc_soot_jimple_ReturnStmt$object;
struct _jc_soot_jimple_ThrowStmt$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_refs	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_nonrefs	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$refs	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$nonrefs	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object;

typedef const struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vmethods	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtable	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtype	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$caseAssignStmt$de19a495d79e10c8(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$caseInvokeStmt$671c80fe05e482dc(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$caseReturnStmt$1559ca8208411026(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$caseThrowStmt$f52f1c60cb1132a4(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$defaultCase$6711cf3c099fadd1(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$getLocal$a441b41cec934e4e(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *);
extern void _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$setLocal$68d90b814eb831c3(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method_info$caseAssignStmt$de19a495d79e10c8;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method_info$caseInvokeStmt$671c80fe05e482dc;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method_info$caseReturnStmt$1559ca8208411026;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method_info$caseThrowStmt$f52f1c60cb1132a4;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method_info$defaultCase$6711cf3c099fadd1;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method_info$getLocal$a441b41cec934e4e;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method_info$setLocal$68d90b814eb831c3;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vmethods {
	void	(*caseAssignStmt$de19a495d79e10c8)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *);
	void	(*caseInvokeStmt$671c80fe05e482dc)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *);
	void	(*caseReturnStmt$1559ca8208411026)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *);
	void	(*caseThrowStmt$f52f1c60cb1132a4)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *);
	void	(*defaultCase$6711cf3c099fadd1)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*getLocal$a441b41cec934e4e)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *);
	void	(*setLocal$68d90b814eb831c3)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractStmtSwitch$vmethods	soot_jimple_AbstractStmtSwitch;
	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vmethods	org_dellroad_jc_cgen_escape_EscapingStmtSwitch;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_refs {
	struct _jc_org_dellroad_jc_cgen_escape_EscapingValueSwitch$object	*escapingValueSwitch;
	struct _jc_object	*local;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$refs {
    _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_refs	org_dellroad_jc_cgen_escape_EscapingStmtSwitch;
    _jc_soot_jimple_AbstractStmtSwitch$sub_refs	soot_jimple_AbstractStmtSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractStmtSwitch$sub_nonrefs	soot_jimple_AbstractStmtSwitch;
    _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_nonrefs	org_dellroad_jc_cgen_escape_EscapingStmtSwitch;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object {
	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtype _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_escape_EscapingStmtSwitch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_escape_EscapingStmtSwitch_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/escape/EscapingStmtSwitch.h <==
// public class org.dellroad.jc.cgen.escape.EscapingStmtSwitch

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 535ab0352e3db9e7 org_dellroad_jc_cgen_escape_EscapingStmtSwitch
// @dep_class d048eaf64ce6dc1a soot_jimple_AbstractStmtSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractStmtSwitch

#include "soot/jimple/AbstractStmtSwitch.h"

#ifndef _JC_org_dellroad_jc_cgen_escape_EscapingStmtSwitch_H_
#define _JC_org_dellroad_jc_cgen_escape_EscapingStmtSwitch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_org_dellroad_jc_cgen_escape_EscapingValueSwitch$object;
struct _jc_soot_Local$object;
struct _jc_soot_jimple_AssignStmt$object;
struct _jc_soot_jimple_InvokeStmt$object;
struct _jc_soot_jimple_ReturnStmt$object;
struct _jc_soot_jimple_ThrowStmt$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_refs	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_nonrefs	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$refs	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$nonrefs	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object;

typedef const struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vmethods	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtable	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtype	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$caseAssignStmt$de19a495d79e10c8(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$caseInvokeStmt$671c80fe05e482dc(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$caseReturnStmt$1559ca8208411026(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$caseThrowStmt$f52f1c60cb1132a4(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$defaultCase$6711cf3c099fadd1(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$getLocal$a441b41cec934e4e(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method$setLocal$68d90b814eb831c3(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method_info$caseAssignStmt$de19a495d79e10c8;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method_info$caseInvokeStmt$671c80fe05e482dc;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method_info$caseReturnStmt$1559ca8208411026;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method_info$caseThrowStmt$f52f1c60cb1132a4;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method_info$defaultCase$6711cf3c099fadd1;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method_info$getLocal$a441b41cec934e4e;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$method_info$setLocal$68d90b814eb831c3;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vmethods {
	void	(*caseAssignStmt$de19a495d79e10c8)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseInvokeStmt$671c80fe05e482dc)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseReturnStmt$1559ca8208411026)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseThrowStmt$f52f1c60cb1132a4)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*defaultCase$6711cf3c099fadd1)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getLocal$a441b41cec934e4e)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *) _JC_JCNI_ATTR;
	void	(*setLocal$68d90b814eb831c3)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractStmtSwitch$vmethods	soot_jimple_AbstractStmtSwitch;
	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vmethods	org_dellroad_jc_cgen_escape_EscapingStmtSwitch;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_refs {
	struct _jc_org_dellroad_jc_cgen_escape_EscapingValueSwitch$object	*escapingValueSwitch;
	struct _jc_object	*local;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$refs {
    _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_refs	org_dellroad_jc_cgen_escape_EscapingStmtSwitch;
    _jc_soot_jimple_AbstractStmtSwitch$sub_refs	soot_jimple_AbstractStmtSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractStmtSwitch$sub_nonrefs	soot_jimple_AbstractStmtSwitch;
    _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$sub_nonrefs	org_dellroad_jc_cgen_escape_EscapingStmtSwitch;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$object {
	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$vtype _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_escape_EscapingStmtSwitch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_escape_EscapingStmtSwitch$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_escape_EscapingStmtSwitch_H_ */
